@@ -17,7 +17,7 @@ def check_schema_exists_sqlite(connection: Connection, name: str) -> bool:
     unconditionally attach it and return `False` always.
     """
     schema_exists = "ATTACH DATABASE ':memory:' AS :schema"
-    connection.execute(text(schema_exists), schema=name)
+    connection.execute(text(schema_exists), {"schema": name})
     return False
 
 
@@ -33,7 +33,6 @@ def check_table_exists_sqlite(
 ) -> bool:
     row = connection.execute(
         table_exists_query(schema),
-        name=name,
-        schema=schema,
+        {"name": name, "schema": schema},
     ).scalar()
     return bool(row)
